@@ -107,6 +107,9 @@ class ProjectVersion(object):
         self.published_timestamp = properties.get(LibKGPropertyName.PUBLISHED_TIMESTAMP)
         self.updated_timestamp = properties.get(LibKGPropertyName.UPDATED_TIMESTAMP)
 
+    def get_label(self):
+        return "ProjectVersion"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
@@ -140,6 +143,9 @@ class ProjectVersionDependency(object):
         self.project_version_number = properties.get(LibKGPropertyName.PROJECT_VERSION_NUMBER)
         self.project_version_platform = properties.get(LibKGPropertyName.PROJECT_VERSION_PLATFORM)
 
+    def get_label(self):
+        return "ProjectVersionDependency"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
@@ -201,6 +207,9 @@ class Repository(object):
         self.watchers_count = properties.get(LibKGPropertyName.WATCHERS_COUNT)
         self.wiki_enabled = properties.get(LibKGPropertyName.WIKI_ENABLED)
 
+    def get_label(self):
+        return "Repository"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
@@ -235,6 +244,9 @@ class RepositoryDependency(object):
         self.repository_ID = properties.get(LibKGPropertyName.REPOSITORY_ID)
         self.repository_name_with_owner = properties.get(LibKGPropertyName.REPOSITORY_NAME_WITH_OWNER)
 
+    def get_label(self):
+        return "RepositoryDependency"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
@@ -264,6 +276,9 @@ class Tag(object):
         self.tag_published_timestamp = properties.get(LibKGPropertyName.TAG_PUBLISHED_TIMESTAMP)
         self.tag_updated_timestamp = properties.get(LibKGPropertyName.TAG_UPDATED_TIMESTAMP)
 
+    def get_label(self):
+        return "Tag"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
@@ -286,6 +301,9 @@ class Platform(object):
         self.platform_name = properties.get(LibKGPropertyName.PLATFORM_NAME)
         self.platform_ID = properties.get(LibKGPropertyName.PLATFORM_ID)
 
+    def get_label(self):
+        return "Platform"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
@@ -325,6 +343,9 @@ class Project(object):
         self.status = properties.get(LibKGPropertyName.STATUS)
         self.updated_timestamp = properties.get(LibKGPropertyName.UPDATED_TIMESTAMP)
 
+    def get_label(self):
+        return "Project"
+
     def __eq__(self, other):
         if type(self) != type(other):
             return False
